# ECHONET Lite Tutorial

神奈川工科大学　スマートハウス研究センター
#### 2019.11.11

履歴  

Date       | Description
:----------|:----------
2019.11.11 | Alpha version release

## 目次

* [Abstract](#Abstract)
* [Prerequite](#Prerequite)
* [1. 基本編](#Chap1)
	* [1.1 基本コンセプト](#Chap1.1)
	* [1.2 メッセージのフレームフォーマット](#Chap1.2)
	* [1.3 基本シーケンス](#Chap1.3)
	* [1.4 Node Profileと機器探索](#Chap1.4)
* [2. 実用編](#Chap2)
	* [2.1 規格書](#Chap2.1)
	* [2.2 ESV](#Chap2.2)
	* [2.3 EOJ](#Chap2.3)
	* [2.4 EPC](#Chap2.4)
	* [2.5 EDT](#Chap2.5)
	* [2.6 機器構成](#Chap2.6)
	* [2.7 起動時処理](#Chap2.7)
	* [2.8 異常処理](#Chap2.8)
	* [2.9 プロパティの値と実装](#Chap2.9)
	* [2.10 複数命令の処理](#Chap2.10)
	* [2.11 スマート電力量メータ](#Chap2.11)
* [3. 発展編](#Chap3)
	* [3.1 SetGet](#Chap3.1)
	* [3.2 現実的な実装について](#Chap3.2)
	* [3.3 遠隔操作設定プロパティ](#Chap3.3)
	* [3.4 送信専用ノード](#Chap3.4)
	* [3.5 ECHONET Liteのバージョン間の違い](#Chap3.5)
* [4. 認証制度](#Chap4)
	* [4.1 エコーネットコンソーシアム](#Chap4.1)
	* [4.2 ECHONET Lite認証](#Chap4.2)
	* [4.3 ECHONET Lite AIF認証](#Chap4.3)
* [付録. メーカコード](#ChapAnnex)

---------------------------------------

## <a id="Abstract">Abstract</a>
　このドキュメントはECHONET Liteプロトコルの技術的なTutorialである。基本編を理解すれば、簡単な制御を実行できる。実用編を理解すれば、ECHONET Liteはほぼわかったことになる。発展編は製品レベルを想定した内容である。第４章ではAIFを含む認証制度について簡単に説明する。

## <a id="Prerequite">Prerequite</a>
IP NetworkとUDP通信の基本知識が必要である。  

## <a id="Terminology">Terminology</a>
|Term |Description
|:-------|:----------
|HEMS    |Home Energy Management System
|メッセージ|一定の形式に従って記述された、機器間で送受信されるひとまとまりのデータ。意味によってリクエスト、レスポンス、通知と呼ぶことがある。
|機器     |ECHONET Liteプロトコルを実装した機器
|EHD     |ECHONET Lite Header
|TID     |Transaction Id
|SEOJ    |Source ECHONET Lite Object
|DEOJ    |Destination ECHONET Lite Object
|ESV     |ECHONET Lite Service
|OPC     |Operation Count
|EPC     |ECHONET Lite Property Code
|PDC     |Property Data Count
|EDT     |ECHONET Lite Data



## <a id="Chap1">1. 基本編</a>
### <a id="Chap1.1">1.1 基本コンセプト</a>
- ECHONET LiteはHEMSを構成するコントローラや機器間の通信プロトコルである
- ECHONET Liteは通信の制御役（coordinator）が不要であり、システム構成を管理する機器も不要である
- システムは通常１台のコントローラと複数の機器で構成されるが、プロトコル的にはコントローラと機器は対等である
- ECHONET LiteはUDP レイヤー上のプロトコル
    - 受信ポート番号: `3610`
    - マルチキャストアドレス: `224.0.23.0`(IPv4), `ff02::1`(IPv6)
    - メッセージは全てバイナリデータで定義されている
- 基本操作は プロパティの`取得` `設定` `通知` である
    - 機器の状態や機能はプロパティとして定義されている
    - プロパティの値を取得するにはGet命令を使う
    - プロパティの値を設定する（操作する）にはSet命令を使う
    - プロパティの値を通知するINF命令を使う

### <a id="Chap1.2">1.2 メッセージのフレームフォーマット</a>
ECHONET Liteのメッセージはバイナリーデータである。メッセージのフレームフォーマットを以下に示す。

```
+---+---+----+----+---+---+----+----+----+---+----+----+----+
|EHD|TID|SEOJ|DEOJ|ESV|OPC|EPC1|PDC1|EDT1|...|EPCn|PDCn|EDTn|
+---+---+----+----+---+---+----+----+----+---+----+----+----+
```

|Element |Data size (byte)|Description
|:-------|:----------:|:-----------
|EHD     |2| ECHONET Lite Header (0x1081)
|TID     |2| Transaction Id
|SEOJ    |3| Source ECHONET Lite Object
|DEOJ    |3| Destination ECHONET Lite Object
|ESV     |1| ECHONET Lite Service
|OPC     |1| Operation Count
|EPC     |1| ECHONET Lite Property Code
|PDC     |1| Property Data Count
|EDT     |N| ECHONET Lite Data

基本編では話を簡単にするために OPC=1 とする。この場合のフレームフォーマットを以下に示す。

```
+-----+-----+------+------+-----+----------+-----+-----+-----+
| EHD | TID | SEOJ | DEOJ | ESV | OPC=0x01 | EPC | PDC | EDT |
+-----+-----+------+------+-----+----------+-----+-----+-----+
```

### EHD: ECHONET Lite Header

ECHONET Liteのメッセージであることを示す固定値（0x1081）である。

### TID: Transaction ID

メッセージのリクエストとレスポンスの対応をつけるためのデータ。リクエストの送信者はメッセージのTIDに任意の値（通常はリクエストの送信ごとにインクリメントした値）を設定してメッセージを送信する。リクエストの受信者は受信したメッセージのTIDの値をレスポンスのメッセージのTIDに設定してメッセージを返信する。

### EOJ: ECHONET Lite Object

EOJは送信元または送信先の機器を示す3byteのデータである。送信元はSEOJ(Source EOJ)、送信先はDEOJ(Destination EOJ)と呼ぶ。EOJの上位2byteで機器の種類を示す。EOJの3byte目は同一種類の機器が複数存在する場合に機器を特定するためのコードである。詳細は2.3 EOJで説明する。

EOJの上位2byteで表す機器の種類の例を以下に示す。

|EOJ (上位2byte) |機器名
|:------|:----------
|0x0130 |家庭用エアコン
|0x027D |蓄電池
|0x0288 |低圧スマート電力量メータ
|0x0290 |一般照明
|0x05FF |コントローラ|Controller
|0x0EF0 |ノードプロファイル|Node profile

### ESV: ECHONET Lite Service
ESV はメッセージのサービスの種類を示す。詳細は2.2 ESVで説明する。以下にESVの例を示す。

| ESV |Symbol|Type    |Description
:-----|:----|:-------|:-----------------------------------------
| 0x62|Get|request |Get property value
| 0x72|Get\_Res|response|Response property value
| 0x61|SetC|request |Set property value
| 0x71|Set\_Res|response|Ack to SetC command(\*)
| 0x73|INF|notification|Inform property value

(\*) Set\_Res はSetCを受信したことに対するレスポンスであって、命令を実行したことに対するレスポンスではない。命令が実行されたかどうかを確認するにはGetコマンドを実行する。

### OPC: Operation Count
１つの命令(operation)は、後述するEPC, PDC, EDTのセットで構成される。１メッセージで複数の命令を送信することが可能で、OPCは１メッセージ内の命令の個数を示す。

### EPC: ECHONET Lite Property Code
機器の設定・状態・機能はプロパティと呼ばれ、１バイトのデータで定義されている。  

### PDC: Property Data Count
後述するEDTのデータサイズを示す。ESV=0x62(Get)の場合はEDTが不要なのでPDC=0となる。

### EDT: ECHONET Lite Data
プロパティの値である。データサイズは可変長。  

##### 家庭用エアコン(EOJ=0x0130)のEPC, EDTの例

| EPC  | プロパティ名 | PDC |EDT
|:-----|:-----------|:---:|:-------
| 0x80|動作状態     | 1|0x30:ON, 0x31:OFF
| 0xA0|風量設定     | 1| ８段階のレベル。0x31...0x38
| 0xB0|運転モード設定| 1|0x42:冷房, 0x43:暖房
| 0xB3|温度設定値   | 1|0~50
| 0xBB|室内温度計測値| 1|-127~125

##### 照明(EOJ=0x0290)のEPC, PDC, EDTの例

| EPC  | プロパティ名 | PDC |EDT
|:-----|:-----------|:---:|:-------
| 0x80|動作状態     | 1|0x30:ON, 0x31:OFF
| 0xB0|照度レベル設定| 1| 0 ~ 100%
| 0xB6|点灯モード設定| 1|0x42:通常灯, 0x43:常夜灯, 0x45:カラー灯
| 0xC0|RGB設定     | 3|RGB各1byte, 0 ~ 255


### <a id="Chap1.3">1.3 基本シーケンス</a>

家庭用エアコンの動作状態(EPC=0x80)を例にして基本シーケンスの説明をする。  

##### プロパティ値の取得
プロパティの取得はリクエストに ESV=0x62(Get) を、レスポンスに ESV=0x72(Get\_Res) を利用する。以下の例ではエアコンがOFF(0x31)であることがわかる。  

```
リクエスト：コントローラ(0x05FF01) -> エアコン(0x013001)
1081 0001 05FF01 013001 62  01  80  00
<--> <--> <----> <----> <-> <-> <-> <->
EHD  TID  SEOJ   DEOJ   ESV OPC EPC PDC
 
レスポンス：エアコン(0x013001) -> コントローラ(0x05FF01)
1081 0001 013001 05FF01 72  01  80  01  31
<--> <--> <----> <----> <-> <-> <-> <-> <->
EHD  TID  SEOJ   DEOJ   ESV OPC EPC PDC EDT
 
```

##### プロパティ値の設定
プロパティの設定はリクエストに ESV=0x61(SetC) を、レスポンスに ESV=0x71(SetC\_Res) を利用する。SetC\_ResはSetCコマンドを受信したことに対するACKの意味であり、実際にプロパティが設定されたかどうかは別途確認が必要である。
以下はエアコンの動作状態をON(EDT=0x30)にする例である。

```
リクエスト：コントローラ(0x05FF01) -> エアコン(0x013001)
1081 0002 05FF01 013001 61  01  80  01  30
<--> <--> <----> <----> <-> <-> <-> <-> <->
EHD  TID  SEOJ   DEOJ   ESV OPC EPC PDC EDT
 
レスポンス：エアコン(0x013001) -> コントローラ(0x05FF01)
1081 0002 013001 05FF01 71  01  80  00
<--> <--> <----> <----> <-> <-> <-> <->
EHD  TID  SEOJ   DEOJ   ESV OPC EPC PDC
 
```

##### プロパティの通知
プロパティの通知は ESV=0x73(INF)を利用する。以下はエアコンの動作状態(EPC=0x80)がON(EDT=0x30)になったことを通知する例である。

```
通知：エアコン(0x013001) -> コントローラ(0x05FF01)
1081 0001 013000 05FF01 73  01  80  01  30
<--> <--> <----> <----> <-> <-> <-> <-> <->
EHD  TID  SEOJ   DEOJ   ESV OPC EPC PDC EDT
 
```

### <a id="Chap1.4">1.4 Node Profileオブジェクトと機器探索</a>
ECHONET Liteで通信を行うには、通信相手のIPアドレスとEOJを知る必要がある。ここではネットワーク内のどのIPアドレスにどのような機器オブジェクト(EOJ)が存在するかを調べる方法を説明する。  
ECHONET Lite機器は、IP通信を行うNode Profileオブジェクトと機器固有の機能を実現する機器オブジェクトで構成される。Node ProfileオブジェクトはIPアドレスに対応して１つ存在する。機器オブジェクトの具体例としては家庭用エアコン、蓄電池、一般照明などがある。一つのIPアドレスに機器オブジェクトが複数個存在する構成も可能である。  
Node Profileオブジェクトと機器オブジェクトの構成の例を以下に示す。IP address 192.168.1.10には家庭用エアコンが１台、IP address 192.168.1.11には蓄電池が１台、IP address 192.168.1.12には一般照明が３台存在する。

```

    192.168.1.10            192.168.1.11            192.168.1.12
  --------+-----------------------+-----------------------+-------
          |                       |                       |
 +-----------------+      +-----------------+      +--------------+
 | Node Profile    |      | Node Profile    |      | Node Profile |
 +-----------------+      +-----------------+      +--------------+
 | Air conditioner |      | Storage battery |      | Lighting-1   |
 +-----------------+      +-----------------+      +--------------+
                                                   | Lighting-2   |
                                                   +--------------+
                                                   | Lighting-3   |
                                                   +--------------+
                 
```
ECHONET Lite通信の送信元(SEOJ)や送信先(DEOJ)は上記のNode Profileオブジェクトや機器オブジェクトを指定する。EOJは3byteで構成され、上位2byteはオブジェクトの種類（例：0x0EF0:Node Profile,0x0130:家庭用エアコン, 0x027D:蓄電池, 0x0290:一般照明)を示し、３byte目は同一種類のオブジェクトを区別するための番号である。Node ProfileオブジェクトのEOJは常に0x0EF001である。以下にEOJの例を示す。

```

    192.168.1.10            192.168.1.11            192.168.1.12
  --------+-----------------------+-----------------------+-------
          |                       |                       |
 +-----------------+      +-----------------+      +---------------+
 | Node Profile    |      | Node Profile    |      | Node Profile  |
 |  EOJ:0x0EF001   |      |  EOJ:0x0EF001   |      |  EOJ:0x0EF001 |
 +-----------------+      +-----------------+      +---------------+
 | Air conditioner |      | Storage battery |      | Lighting-1    |
 |  EOJ:0x013001   |      |  EOJ:0x027D01   |      |  EOJ:0x029001 |
 +-----------------+      +-----------------+      +---------------+
                                                   | Lighting-2    |
                                                   |  EOJ:0x029002 |
                                                   +---------------+
                                                   | Lighting-3    |
                                                   |  EOJ:0x029003 |
                                                   +---------------+
                 
```

Node profileオブジェクトはそのIPアドレスに存在する機器オブジェクトの情報をプロパティ「自ノードインスタンスリストS」(EPC=0xD6)として持つ。このプロパティのデータフォーマットは以下のとおり。<br>

>　1byte目: 機器オブジェクトの個数<br>
>　2byte目以降: EOJの列挙

例えば、上記のIPアドレス(192.168.1.10, 192.168.1.11, 192.168.1.12)に対応するそれぞれのNode Profileオブジェクトの自ノードインスタンスリストSの値は、「01013001」「01027D01」「03028801028802028803」となる。したがってネットワーク内の機器に`「DEOJ=0x0EF001, ESV=0x62(Get), EPC=0xD6」`のメッセージを送れば、それぞれのIPアドレスにどのような機器が存在するかがわかる。

ところでECHONET Lite機器のIPアドレスは通常DHCPで設定されるので、通信相手のIPアドレスがわからない。そこでUDPのマルチキャストを利用してネットワーク内の全ての機器にメッセージを送信する。ECHONET LiteはUDPマルチキャストアドレスとして224.0.23.0を登録してある。  

つまり、**`「DEOJ=0x0EF001, ESV=0x62(Get), EPC=0xD6」のメッセージを IP=224.0.23.0 にマルチキャスト`**することで機器探索を行うことができる。

以下に機器探索のリクエストとレスポンスの例を示す。

```
リクエスト（Destination IP: 224.0.23.0）
1081 0001 05FF01 0EF001 62  01  D6  00
<--> <--> <----> <----> <-> <-> <-> <->
EHD  TID  SEOJ   DEOJ   ESV OPC EPC PDC
 
レスポンス（Source IP: 192.168.1.10）
1081 0001 0EF001 05FF01 72  01  D6  04  01013001
レスポンス（Source IP: 192.168.1.11）
1081 0001 0EF001 05FF01 72  01  D6  04  01027D01
レスポンス（Source IP: 192.168.1.12）
1081 0001 0EF001 05FF01 72  01  D6  0A  03029001029002029003
<--> <--> <----> <----> <-> <-> <-> <-> <------------------>
EHD  TID  SEOJ   DEOJ   ESV OPC EPC PDC EDT
```
　
## <a id="Chap2">2. 実用編</a>
### <a id="Chap2.1">2.1 規格書</a>
ECHONET Liteの規格書は以下の３つのドキュメントで構成され、[エコーネットコンソーシアムのホームページ](https://echonet.jp/spec_g/#standard-01)からダウンロードできる。

- ECHONET Lite規格書
- ECHONET Liteシステム設計指針
- APPENDIX ECHONET機器オブジェクト詳細規定

#### ECHONET Lite規格書
「ECHONET Lite規格書」は規格の本体である。第１部から第４部で構成され、約300ページの分量がある。本チュートリアルを理解すれば目を通す機会は少ない。必要に応じて第２部を参照すること。  

ECHONET Lite規格の最新版は2019年8月時点でVer. 1.13である。機器が実装しているECHONET LiteのバージョンはNode profileオブジェクト(EOJ=0x0EF001)のVersion情報プロパティ(EPC=0x82)として取得できる。本TutorialはV1.13を前提に記述している。通常の機器制御においてECHONET LiteのVersionを意識する必要はない。  

#### ECHONET Liteシステム設計指針
「ECHONET Liteシステム設計指針」は実装のガイドラインである。本チュートリアルを理解すれば目を通す機会は少ない。

#### APPENDIX ECHONET機器オブジェクト詳細規定
「APPENDIX ECHONET機器オブジェクト詳細規定」（以下APPENDIXと略す）には機器オブジェクト毎のプロパティの仕様が記述されている。機器を制御するためにはこの規格書を参照する必要がある。半年に１度程度改定があり、そのバージョンをRelease と表記している。Releaseは"A"から始まり2019年8月時点では"L"が最新である。プロパティの仕様はbackward compatibilityが考慮されていない(\*)ため、コントローラは機器が実装しているReleaseの仕様に合わせてメッセージを送信したり、受信したメッセージを解釈する必要がある。機器が実装しているReleaseのバージョンは機器オブジェクトの規格Version情報プロパティ(EPC=0x82)として取得できる。  

(\*) 例：電動ブラインド(EOJ=0x0260)の開度レベル(EPC=0xE1)はRelease A\~Cでは8段階のレベル(0x31\~0x38)であったが、Release D以降では数値(0\~100%)になった。　

なお、ノードプロファイルオブジェクトのプロパティ情報は「ECHONET Lite規格書」の第２部6.10に記載されている。

以下にAPPENDIX ECHONET機器オブジェクト詳細規定の中の一般照明の一部を示す。プロパティの情報が表にまとめられている。この表の後に各プロパティの説明がある。ここに表には記載されていない追加情報（例：未設定に対応する値は0xFF）が記述されている場合があるので注意すること。

![一般照明](_graphics/appendix_jp.png "一般照明")

### <a id="Chap2.2">2.2 ESV (ECHONET Lite service code) </a>

ECHONET Liteのメッセージの種類をサービスと呼び、ESV(ECHONET Lite service code)として1byteのデータで定義している(reference:第２部3.2.5, 4.2.3)。サービスは以下の４種類に分類される。サービスの実装については第３章を参照のこと。

- リクエスト: プロパティ値のREAD, WRITE, 通知のリクエスト
    - ESV=0x60, 0x61, 0x62, 0x63, 0x6E
- レスポンス（正常）: リクエストを正常に受け付けた場合のレスポンス (ESV=0x71, 0x72, 0x73, 0x7E)
- レスポンス（異常）: リクエストを正常に受け付けられない場合のレスポンス。不可応答:SNA(\*)と呼ぶ。(ESV=0x50, 0x51, 0x52, 0x53, 0x5E)
- 自発的通知: プロパティ値の自発的通知 (ESV=0x73, 0x74)

(\*) 規格書には明記されていないが、Service Not Availableの略だと推定する。

#### リクエスト＆レスポンス

|ESV<br>リクエスト|Symbol|Description| ESV<br>レスポンス<br>（正常）|Symbol|ESV<br> レスポンス <br>（異常）|Symbol|Note
|:---|:-----|:-------|:-------|:-------|:-------|:-------|:-------
|0x60| SetI(\*1) |Write(応答不要) |-|-|0x50|SetI\_SNA|お勧めしない
|0x61| SetC(\*2) |Write(応答必要) |0x71|Set\_Res(\*3)|0x51|SetC\_SNA|よく使われる
|0x62| Get  |Read           |0x72|Get\_Res|0x52|Get\_SNA|よく使われる
|0x63| INF\_REQ(\*4)|通知        |0x73|INF(\*5)|0x53|INF\_SNA(\*6)|お勧めしない
|0x6E| SetGet(\*7)|Write&Read  |0x7E|SetGet\_Res|0x5E|SetGet\_SNA|お勧めしない

(\*1) 規格書には明記されていないが、Set with Ignorance の略だと推定する。  
(\*2) 規格書には明記されていないが、Set with Confirmation の略だと推定する。  
(\*3) Set\_ResはSetCコマンドを受信したことに対する確認(ACK)の意味である。  
(\*4) INF\_REQをマルチキャスト送信することはネットワークの輻輳の可能性があり望ましくない(reference:システム設計指針2.4.1)。  
(\*5) INF\_REQのレスポンスとしてのINFはマルチキャスト(reference:第２部4.2.3.5)。  
(\*6) INF\_SNAはユニキャスト(reference:第２部4.2.3.5)。  
(\*7) SetGetのフレーム構成は1.2で説明したものとは異なる。3.1 SetGetで説明する。  

- Setに関してはSetCを使えばよく、SetIを積極的に使う理由はない。  
- INF\_REQはレガシーコマンドである。使う必要がない。  
- SetGetのコマンドの設計思想(reference:第２部4.2.3.4)は複数のSetやGetの命令を１メッセージで送信することであり、それぞれの命令の実行順は機器依存としているため、Setしたプロパティの値を確認するためには利用できない。またエラー処理が複雑である。したがって無理にSetGetを使うよりもSetとGetを別々に実行することをお勧めする。

#### 自発的通知
オブジェクト（Node profileオブジェクトまたは機器オブジェクト）が自発的にINFまたはINFCを利用してプロパティ値を伝える場合について説明する(reference:第２部6.2.4)。

|ESV<br>通知 |Symbol|Description| ESV<br>レスポンス|Symbol|Note
|:------------------|:-----|:----------|:---------------|:-----|:------
|0x73| INF |通知(応答不要) |-|-|よく使われる
|0x74| INFC |通知(応答必要) |INFC\_Res|0x7A|あまり使われない<br>ユニキャストのみ

- 「状変時アナウンス」が必須であるプロパティを実装する場合、プロパティ値が変った場合には必ずマルチキャストでINFを送信する。DEOJ にはノードプロファイル(0x0EF001) を設定する。
- INFCはユニキャストのみ(reference:第２部4.2.3.6)。

#### ESVとアクセスルール
APPENDIXのアクセスルール欄と必須欄の説明を以下に記述する。  
- アクセスルール欄はどのサービス(ESV)に対応しているかを示す。(reference:第２部6.2.5)
    - Set: 0x60(SetI), 0x61(SetC), 0x6E(SetGet)
    - Get: 0x62(Get), 0x6E(SetGet), 0x63(INF\_REQ)
    - Anno: 0x63(INF\_REQ)
        - アクセスルールがAnnoであるプロパティは、Node profileのEPC=0xD5のみである
- 必須欄はアクセスルールのSetやGetに対応するサービスの実装に関する情報である。アクセスルールにSetやGetの記載があり、必須欄が「◯」の場合はそのプロパティが必ず実装されていることを示し、空白の場合はそのプロパティが実装されるかどうかは機器依存であることを示す。
- 状変時アナウンス欄に「◯」が記載されているプロパティを実装する場合は、プロパティ値に変化があった時にINFまたはINFCをマルチキャスト(DEOJ=0x0EF001)送信する。(reference:第２部6.2.4)



### <a id="Chap2.3">2.3 EOJ (ECHONET object) </a>

ECHONET Liteのメッセージの送信または受信を行う主体をECHONET オブジェクト(EOJ)呼ぶ。EOJは3byteで構成され、1byte目をクラスグループコード、2byte目をクラスコード、3byte目をインスタンスコードと呼ぶ(reference:第２部3.2.4)。
クラスグループコードは機器種別の大分類（例 0x01:空調関連クラスグループ）クラスコードは小分類（例 空調機器関連クラスグループの0x30は家庭用エアコン）と定義されているが、実用的にはこの2byteで機器種別を表しているので、このドキュメントではEOJの上位2byteをDevice typeと呼ぶ。インスタンスコードは同一Device typeの機器が複数存在する場合に機器を特定するためのコードで、機器側が設定する値(1~255)である。  

- Device type: 0x0F00~0FFF はユーザーが自由に定義して使えるコードである。
- DEOJのインスタンスコードの0x00はワイルドカードで、同一種類の機器全てを送信先に設定する。例えばDEOJ=0x029000とすると、送信先IPアドレスの全ての照明に対して同一のメッセージを送ることができる。
- Node profileのEOJは0x0EF001（ただし送信専用ノード(3.4 送信専用ノード参照)の場合は0x0EF002）。
- インスタンスコードは機器が設定するが、その値に関しては規則やガイドラインは存在しない。多くの場合その値は0x01であり、同一Device typeの機器が複数存在する場合にはインクリメントすることが多いが、それを前提として制御してはいけない。

以下にDevice typeの例を示す

| Device type | Device name| |Device type | Device name| |Device type | Device name
|:------------|:-----------|:---|:------------|:------------|:----|:------------|:------------
| 0x000D | 照度センサ || 0x0272 | 瞬間式給湯器|| 0x0288 | 低圧スマート<br>電力量メータ
| 0x0011 | 温度センサ || 0x0273 | 浴室暖房乾燥機|| 0x028A | 高圧スマート<br>電力量メータ
| 0x0012 | 湿度センサ || 0x0279 | 住宅用太陽光発電|| 0x0290 | 一般照明
| 0x0022 | 電力量センサ|| 0x027A | 冷温水熱源機|| 0x0291 | 単機能照明
| 0x002D | 気圧センサ || 0x027B | 床暖房|| 0x02A1 | 電気自動車充電器
| 0x0130 | 家庭用エアコン|| 0x027C | 燃料電池|| 0x02A6 | ハイブリッド給湯器
| 0x0133 | 換気扇 || 0x027D | 蓄電池|| 0x03B7 | 冷凍冷蔵庫
| 0x0135 | 空気清浄機|| 0x027E | 電気自動車充放電器|| 0x03B8 | オーブンレンジ
| 0x0260 | 電動ブラインド|| 0x0280 | 電力量メータ|| 0x03B9 | クッキングヒータ
| 0x0263 | 電動雨戸 || 0x0281 | 水力量メータ|| 0x03D3 | 洗濯乾燥機
| 0x026B | 電気温水器|| 0x0282 | ガスメータ|| 0x05FD | スイッチ
| 0x026F | 電気錠 || 0x0287 | 分電盤メータリング|| 0x05FF | コントローラ

### <a id="Chap2.4">2.4 EPC </a>

#### 2.4.1 機器オブジェクトのEPC

　機器オブジェクトのプロパティは１バイトのEPCで定義され、Super classのプロパティ(reference:APPENDIX第２章)と、機器オブジェクトごとのプロパティ(reference:APPENDIX第３章)で定義されている。Super classのプロパティは全ての機器で共通であり、機器オブジェクトごとのプロパティでオーバーライドされる場合がある。<br>
　Super classのプロパティを以下に示す。機器オブジェクトごとのプロパティはAPPENDIX第３章を参照すること。

##### Super class

|  EPC | プロパティ名称|アクセス<br>ルール|必須|状変時<br>アナウンス|Note
|:-----|:----------------|:----|:----|:----|:----
| 0x80 | 動作状態 |Set<br>Get|x<br>◯|◯|
| 0x81 | 設置場所 |Set/Get|◯|◯|(\*1)
| 0x82 | 規格Version情報 |Get|◯|x|(\*2)
| 0x83 | 識別番号 |Get|x|x|(\*3) 
| 0x84 | 瞬時消費電力計測値 |Get|x|x
| 0x85 | 積算消費電力計測値 |Get|x|x
| 0x86 | メーカ異常コード |Get|x|x
| 0x87 | 電流制限設定 |Set/Get|x|x
| 0x88 | 異常発生状態 |Get|◯|◯
| 0x89 | 異常内容 |Get|x|x
| 0x8A | メーカコード |Get|◯|x
| 0x8B | 事業場コード |Get|x|x
| 0x8C | 商品コード |Get|x|x
| 0x8D | 製造番号 |Get|x|x
| 0x8E | 製造年月日 |Get|x|x
| 0x8F | 節電設定 |Set/Get|x|x
| 0x93 | 遠隔操作設定 |Set/Get|x|x|(\*4)
| 0x97 | 現在時刻設定 |Set/Get|x|x
| 0x98 | 現在年月日設定 |Set/Get|x|x
| 0x99 | 電力制限設定 |Set/Get|x|x
| 0x9A | 積算運転時間 |Get|x|x
| 0x9D | 状変アナウンスプロパティマップ |Get|◯|x
| 0x9E | Setプロパティマップ |Get|◯|x
| 0x9F | Getプロパティマップ |Get|◯|x

(\*1) プロパティ値は1byte or 17byte。<br>　1byteの場合はbitmap（reference:APPENDIX2.2) 0x00:未設定, 0xFF:不定。<br>
(\*2) 実装しているAPPENDIXのRelease version。<br>　1st,2nd byte:0x00(Release Aを除く)。<br>　3rd byte:Release versionをASCII codeで表す。Aのみ小文字(0x61)、B以降は大文字(B:0x42...L:0x4C)。<br>　4th byte:0x00<br>
(\*3) 0xFE + メーカコード + ユニークID(13byte)<br>
(\*4) 3.3 遠隔操作設定を参照

EPCは値の範囲で以下のようにカテゴリー分けされている(reference:第２部3.2.7)。

| EPC        |Category |Example
:------------|:----|:-------|
| 0x00 ~ 0x7F| reserved|
| 0x80 ~ 0x9F| Common properties across devices|0x80: 動作状態
| 0xA0 ~ 0xEF| Specific properties to each device|0xB0<br>エアコン: 運転モード</br>照明: 照度レベル
| 0xF0 ~ 0xFF| User defined properties|

Super classのプロパティはEPC=0x80~0x9F のうち以下のEPCを除いたものである。これらは必要に応じて機器オブジェクト側で記述される。

|  EPC | プロパティ名称
|:-----|:------------
| 0x90 | ONタイマ予約設定
| 0x91 | ONタイマ時刻設定
| 0x92 | ONタイマ相対時間設定
| 0x94 | OFFタイマ予約設定
| 0x95 | OFFタイマ時刻設定
| 0x96 | OFFタイマ相対時間設定
| 0x9B | (reserved for legacy)
| 0x9C | (reserved for legacy)

#### 2.4.2 Node profileオブジェクトのEPC
　Node profileオブジェクトのプロパティは１バイトのEPCで定義され、Super class(reference:第２部6.10.1)と、Node profileオブジェクトのプロパティ(reference:第２部6.11.1)で定義されている。Node profileオブジェクトのSuper classと機器オブジェクトのSuper classは異なる。Node profileオブジェクトの全て（Super classを含む）のプロパティを以下に示す。

|  EPC | プロパティ名称|アクセス<br>ルール|必須|状変時<br>アナウンス|note
|:-----|:----------------|:----|:----|:----|:----
| 0x80 | 動作状態 |Set<br>Get|x<br>◯ |◯
| 0x82 | Version情報 |Get|◯|x|(\*1)
| 0x83 | 識別番号 |Get|◯|x|(\*2)
| 0x88 | 異常発生状態 |Get|x|x
| 0x89 | 異常内容 |Get|x|x
| 0x8A | メーカコード |Get|◯|x
| 0x8B | 事業場コード |Get|x|x
| 0x8C | 商品コード |Get|x|x
| 0x8D | 製造番号 |Get|x|x
| 0x8E | 製造年月日 |Get|x|x
| 0x9D | 状変アナウンスプロパティマップ |Get|◯|x
| 0x9E | Set プロパティマップ |Get|◯|x
| 0x9F | Get プロパティマップ |Get|◯|x
| 0xBF | 個体識別情報 |Set/Get|x|x|
| 0xD3 | 自ノードインスタンス数 |Get|◯|x|(\*3)
| 0xD4 | 自ノードクラス数 |Get|◯|x|(\*4)
| 0xD5 | インスタンスリスト通知 |Anno|◯|◯|(\*5)
| 0xD6 | 自ノードインスタンスリストS |Get|◯|x|(\*5)
| 0xD7 | 自ノードクラスリストS |Get|◯|x|(\*3)

(\*1) ECHONET Lite規格のversion。<br>　1バイト目：メジャーバージョン<br>　2バイト目：マイナーバージョン<br>　3バイト目：メッセージ形式をbitmapで示す<br>　4バイト目：0x00<br>　例 0x010D0100: V1.13<br>
(\*2) 0xFE + メーカコード + ユニークID(13byte)。<br>
(\*3) ノードプロファイルクラスを含まない。<br>
(\*4) ノードプロファイルクラスを含む。<br>
(\*5) EPC=0xD5と0xD6のEDTは同じ内容。<br>

Node profileオブジェクトと機器オブジェクトのSuper classの違いを以下に示す。

EPC  | Node profile object | 機器オブジェクト | Note
:----|:----------------|:----|:----
0x81 | Not applicable| 設置場所 |
0x82 | Version情報     | 規格Version情報| ECHONET Lite version：Node profile object<br>Appendix version：機器オブジェクト
0x83 | 識別番号        | 識別番号 | アクセスルール：必須(Node profile object)<br>アクセスルール：非必須(機器オブジェクト)
0x84 | Not applicable | 瞬時消費電力計測値 
0x85 | Not applicable | 積算消費電力計測値
0x86 | Not applicable | メーカ異常コード
0x87 | Not applicable | 電流制限設定
0x88 | 異常発生状態     | 異常発生状態 | アクセスルール：非必須(Node profile object)<br>アクセスルール：必須(機器オブジェクト)
0x8F | Not applicable | 節電動作設定
0x93 | Not applicable | 遠隔操作設定
0x97 | Not applicable | 現在時刻設定
0x98 | Not applicable | 現在年月日設定
0x99 | Not applicable | 電力制限定
0x9A | Not applicable | 積算運転時間

#### 2.4.3 Atomic operation
いくつかの操作を組み合わせてそれらがひとつの操作に見えるものを情報工学においては atomic operationと呼ぶ。以下に、ECHONET Liteにおいてatomic operationと言えるEPCを示す。2nd EPCを実行(Get)する前に1st EPCの実行(SetC)が必要である。

| EOJ | 機器<br>オブジェクト名|1st<br>EPC|プロパティ名|2nd<br>EPC|プロパティ名
|:-----|:--------------|:----|:----|:----|:---
|0x027E|電気自動車<br>充放電器|0xCD|車両接続確認|0xC7|車両接続・充放電可否状態
|0x0287|分電盤<br>メータリング|0xB2|積算電力量計測チャンネル<br>範囲指定（片方向）|0xB3|積算電力量計測値リスト<br>（片方向）
|-|-|0xB4|瞬時電流計測チャンネル<br>範囲指定（片方向）|0xB5|瞬時電流計測値リスト<br>（片方向）
|-|-|0xB6|瞬時電力計測チャンネル<br>範囲指定（片方向）|0xB7|瞬時電力計測値リスト<br>（片方向）
|-|-|0xB9|積算電力量計測チャンネル<br>範囲指定（双方向）|0xBA|積算電力量計測値リスト<br>（双方向）
|-|-|0xBB|瞬時電流計測チャンネル<br>範囲指定（双方向）|0xBC|瞬時電流計測値リスト<br>（双方向）
|-|-|0xBD|瞬時電力計測チャンネル<br>範囲指定（双方向）|0xBE|瞬時電力計測値リスト<br>（双方向）
|-|-|0xC5|積算履歴収集日 |0xC3|積算電力量計測値履歴<br>（正方向）
|0x0288|低圧スマート<br>電力量メータ|0xE5|積算履歴収集日１|0xE2|積算電力量計測値履歴1<br>（正方向計測値）
|-|-|0xE5|積算履歴収集日１|0xE4|積算電力量計測値履歴1<br>（逆方向計測値）
|-|-|0xED|積算履歴収集日２|0xEC|積算電力量計測値履歴2<br>（正方向、逆方向計測値）
|0x028A|高圧スマート<br>電力量メータ|0xE1|積算履歴収集日|0xC6|需要電力計測値履歴
|-|-|0xE1|積算履歴収集日|0xCE|力測積算無効電力量<br>（遅れ）計測値履歴
|-|-|0xE1|積算履歴収集日|0xE7|積算有効電力量計測値履歴
|0x02A1|電気自動車<br>充電器|0xCD|車両接続確認|0xC7|車両接続・充電可否状態

### <a id="Chap2.5">2.5 EDT</a>
EDTはバイナリーデータであり、その値をどのように解釈するかはEPCごとに異なる。その仕様はAPPENDIXのプロパティ内容、値域、データ型、データサイズ、単位に記述されている。数値、状態、レベルの３種類のデータタイプがよく使われている。  

#### 数値
数値の場合、データ型欄にデータのサイズとsigned/unsingedの情報がC言語のキーワードを利用して記述されている。以下にエアコン(EOJ=0x0130)の温度設定値(EPC=0xB3)の記述を例として示す。

![Fig-0130-B3](_graphics/Fig-0130-B3_jp.png "Fig-0130-B3")

少数を含む値を扱う場合は、単位欄に係数が記述されている。例えばエアコンの相対温度設定値(EPC=0xBF)の場合、EDT値が25であれば2.5℃と解釈する。

![Fig-0130-BF](_graphics/Fig-0130-BF_jp.png "Fig-0130-BF")

データ型ごとにアンダーフローとオーバーフローに対応する値が定義されている(reference:第２部6.2.2)。例えばGETで取得したEDTのデータ型がunsigned charでその値が0xFF(255)の場合、機器内部の値は254以上であることを示す。

|データ型|データサイズ|アンダーフロー|オーバーフロー
|:---|:-----|:-------|:-------
|signed char | 1 byte |0x80      |0x7F
|signed short| 2 byte |0x8000    |0x7FFF
|signed long | 4 byte |0x80000000|0x7FFFFFFF
|unsigned char | 1 byte |0xFE      |0xFF
|unsigned short| 2 byte |0xFFFE    |0xFFFF
|unsigned long | 4 byte |0xFFFFFFFE|0xFFFFFFFF

#### 状態
電源のON/OFFやエアコンの運転モードの冷房・暖房などの状態を特定の値に対応させることで、EDTで状態を扱うことができる。以下にエアコン(EOJ=0x0130)の運転モード設定(EPC=0xB0)の記述を例として示す。

![Fig-0130-B0](_graphics/Fig-0130-B0_jp.png "Fig-0130-B0")

#### レベル
エアコンの風量設定などの強弱のレベル設定において、レベル値を特定の値に対応させることで、EDTでレベルを扱うことができる。特に８段階のレベルを0x31(Level-1)~0x38(Level-8)にマッピングする定義はよく使われる。以下にエアコン(EOJ=0x0130)の風量設定(EPC=0xA0)の記述を例として示す。

![Fig-0130-A0](_graphics/Fig-0130-A0_jp.png "Fig-0130-A0")

#### 複数データ
EDTに複数データをパッキングすることもある。以下の照明(EOJ=0x0290)のRGB設定(EPC=0xC0)例では、１バイト目はR、２バイトめはG、３バイト目はBの値であることを示す。。

![Fig-0290-C0](_graphics/Fig-0290-C0_jp.png "Fig-0290-C0")

以下の低圧スマート電力量メータ(EOJ-0x0288)の積算電力量計測値履歴１(EPC=0xE2)の例では、最初の２バイトは日にちを示し、それ以降は48個の電力量（４バイト）を示す。

![Fig-0288-E2](_graphics/Fig-0288-E2_jp.png "Fig-0288-E2")

### <a id="Chap2.6">2.6 Node profileオブジェクトと機器オブジェクトの構成</a>
ECHONET Lite機器のNode profileオブジェクトと機器オブジェクト(Device object)の構成は、下図のような３種類が考えられる。

```
  (A)     (B)            (C)
---+-------+--------------+-----
   |       |              |       
 +---+  +-----+     +-----------+
 | N |  |  N  |     |     N     |
 | D |  |D D D|     +-----------+
 +---+  +-----+      |         |
                   +---+     +---+
                   | D | . . | D |
                   +---+     +---+

N:Node profile object, D:Device object
```

(A) 基本構成：製品がNode profileと１つの機器オブジェクトで構成される場合  
(B) 一つの製品がNode profileと複数の機器オブジェクトで構成される場合  
　例：床暖房が、床暖房オブジェクトと冷温水熱源器オブジェクトで構成されている場合  
(C) 独立した複数の製品が同一Node profileオブジェクトを共用する場合。Node profileオブジェクトと機器オブジェクト間の接続は特定小電力無線、BluetoothやWiSUN-HANなどのproprietryな通信も利用可能  
　例：Panasonic AiSEG, Toshiba Feminity  

(B)や(C)の構成の場合、Node profileのEPC=0xD5, D6のInstance listには複数の機器オブジェクトのEOJが記述される。  

### <a id="Chap2.7">2.7 起動時処理</a>
#### 2.7.1 機器  

機器は起動時やIPアドレス変更時にインスタンスリストをマルチキャスト（宛先IP=224.0.23.0）して、新規の機器がネットワークに参加したことを通知する。  

```
Destination IP: 224.0.23.0
SEOJ: 0x0EF001
DEOJ: 0x0EF001
ESV:  0x73(INF)
OPC:  1
EPC:  0xD5
EDT:  自ノード内のインスタンスリスト
```
例：家庭用エアコンの場合

```
コントローラ　　　　　　　　                          エアコン
(IP=192.168.1.1)　　　　　　　                 (IP=192.168.1.2)
(EOJ=0x05FF01)　　　　　　　                   (EOJ=0x013001)
    |  IP SRC:192.168.1.2, DST:224.0.23.0           |
    |  1081 0001 0EF001 0EF001 73 01 D5 04 01013001 |
    | <-------------------------------------------- |
    |                                               |
```

#### 2.7.2 コントローラ  

コントローラは起動時に機器を探索し、その後操作に必要な情報を各機器から取得する。ここでは最低限必要な動作について説明する。  

1) インスタンスリストの取得

ネットワーク内の機器を探索するためにインスタンスリストのリクエストをマルチキャスト（宛先IP=224.0.23.0）する。インスタンスリストのレスポンスから、機器毎のIPアドレスとEOJがわかる。
  

```
Destination IP: 224.0.23.0
SEOJ: 0x05FF01
DEOJ: 0x0EF001
ESV:  0x62(GET)
OPC:  1
EPC:  0xD6

```

例：ネットワーク内にエアコンと照明がある場合

```
コントローラ                         　　　　　　　　 エアコン              　　                        照明
(IP=192.168.1.1)　　　　　　　                 (IP=192.168.1.2)　　                          (IP=192.168.1.3)
(EOJ=0x05FF01)　　　　　　　                   (EOJ=0x013001)　　                            (EOJ=0x029001)
    |  IP SRC:192.168.1.1, DST:224.0.23.0           |                                              |
    |  1081 0001 0EF001 0EF001 62 01 D6 00          | IP SRC:192.168.1.1, DST:224.0.23.0           |
    | --------------------------------------------> | 1081 0001 0EF001 0EF001 62 01 D6 00          |
    | -------------------------------------------------------------------------------------------> |
    |                                               |                                              |
    |  IP SRC:192.168.1.2, DST:192.168.1.1          |                                              |
    |  1081 0001 0EF001 0EF001 72 01 D6 04 01013001 |                                              |
    | <-------------------------------------------- |                                              |
    |                                               |                                              |
    |                                               | IP SRC:192.168.1.3, DST:192.168.1.1          |
    |                                               | 1081 0001 0EF001 0EF001 72 01 D6 04 01029001 |
    | <------------------------------------------------------------------------------------------- |

```

2) 機器オブジェクトの規格バージョン情報の取得

機器のプロパティは規格バージョン(Appendix version)によって定義が異なる場合がある。したがって機器の規格バージョン情報プロパティの値をあらかじめ取得しておく必要がある。

```
Destination IP: IP address of the device
SEOJ: 0x05FF01
DEOJ: EOJ of the device object
ESV:  0x62(GET)
OPC:  1
EPC:  0x82
```

例

```
コントローラ                         　　　　　　　　 エアコン
(IP=192.168.1.1)　　　　　　　                 (IP=192.168.1.2)
(EOJ=0x05FF01)　　　　　　　                   (EOJ=0x013001)
    |  IP SRC:192.168.1.1, DST:192.168.1.2          |
    |  1081 0002 05FF01 013001 62 01 82 00          |
    | --------------------------------------------> |
    |                                               |
    |  IP SRC:192.168.1.2, DST:192.168.1.1          |
    |  1081 0002 013001 05FF01 72 01 82 04 00004B00 |
    | <-------------------------------------------- |
```


3) Node profileの識別番号(EPC=0x83)の取得  
機器オブジェクトの識別には、IP addressとEOJを利用する。機器のIP addressは通常DHCPで設定するため、機器の電源を入れ直した場合や一定時間後に機器のIP addressが変更される場合がある。IP addressと機器の対応を追跡するには、必須プロパティの一つであるNode profileの識別番号(EPC=0x83)を利用する。識別番号は全てのECHONET Lite機器を通じてユニークな値であることが定められている。なお、機器オブジェクトにも識別番号(EPC=0x83)が定義されているが必須ではない。

```
Destination IP: IP address of the device
SEOJ: 0x05FF01
DEOJ: EOJ of the device object
ESV:  0x62(GET)
OPC:  1
EPC:  0x83
```

例

```
コントローラ                         　　　　　　　　 エアコン
(IP=192.168.1.1)　　　　　　　                 (IP=192.168.1.2)
(EOJ=0x05FF01)　　　　　　　                   (EOJ=0x013001)
    |  IP SRC:192.168.1.1, DST:192.168.1.2          |
    |  1081 0003 05FF01 013001 62 01 83 00          |
    | --------------------------------------------> |
    |                                               |
    |  IP SRC:192.168.1.2, DST:192.168.1.1          |
    |  1081 0003 013001 05FF01 72 01 83 11 FE000069000102030405060708090A0B0C
    | <-------------------------------------------- |
```

4) 機器オブジェクトのプロパティマップ(EPC=0x9D, 9E, 9F)の取得  

必須プロパティ以外のプロパティにアクセスする場合、対象の機器がどのプロパティを実装しているかをあらかじめ知っておく必要がある。そのために状変アナウンスプロパティマップ(EPC=0x9D), Setプロパティマップ(0x9E), Getプロパティマップ(0x9F)を取得する。プロパティマップはプロパティ数が15以下の場合はEPCの値がそのまま列挙されるが、16以上の場合はbitmapで記述される(reference:APPENDIX 付録１)。

Request:

```
Destination IP: IP address of the device
SEOJ: 0x05FF01
DEOJ: EOJ of the device object
ESV:  0x62(Get)
OPC:  1
EPC:  0x9D, 0x9E, 0x9F
```

Response(EPCの個数が15以下の場合):

```
ESV:  0x62(Get\_Res)
EDT:  1byte目:EPCの個数、2byte目以降：EPCのリスト
Example of EDT: 04808FB0B3
```

Response(EPCの個数が16以上の場合):

```
ESV:  0x62(Get\_Res)
OPC:  17
EDT:  1byte目:EPCの個数、2byte目以降：EPCを表すbitmap(以下の表を参照)
Example of EDT: 160B010109000000010101030303030303
(EPC: 80,81,82,83,87,88,89,8A,8B,8C,8D,8E,8F,90,9A,9B,9C,9D,9E,9F,B0,B3)

```

bitmap of EPC (bit value 1:implemented, 0:not implemented)

|byte\bit|bit-7|bit-6|bit-5|bit-4|bit-3|bit-2|bit-1|bit-0|
|:------|:----|:----|:----|:----|:----|:----|:----|:----|
|byte-2 |0xF0 |0xE0 |0xD0 |0xC0 |0xB0 |0xA0 |0x90 |0x80 |
|byte-3 |0xF1 |0xE1 |0xD1 |0xC1 |0xB1 |0xA1 |0x91 |0x81 |
|byte-4 |0xF2 |0xE2 |0xD2 |0xC2 |0xB2 |0xA2 |0x92 |0x82 |
|byte-5 |0xF3 |0xE3 |0xD3 |0xC3 |0xB3 |0xA3 |0x93 |0x83 |
|byte-6 |0xF4 |0xE4 |0xD4 |0xC4 |0xB4 |0xA4 |0x94 |0x84 |
|byte-7 |0xF5 |0xE5 |0xD5 |0xC5 |0xB5 |0xA5 |0x95 |0x85 |
|byte-8 |0xF6 |0xE6 |0xD6 |0xC6 |0xB6 |0xA6 |0x96 |0x86 |
|byte-9 |0xF7 |0xE7 |0xD7 |0xC7 |0xB7 |0xA7 |0x97 |0x87 |
|byte-10|0xF8 |0xE8 |0xD8 |0xC8 |0xB8 |0xA8 |0x98 |0x88 |
|byte-11|0xF9 |0xE9 |0xD9 |0xC9 |0xB9 |0xA9 |0x99 |0x89 |
|byte-12|0xFA |0xEA |0xDA |0xCA |0xBA |0xAA |0x9A |0x8A |
|byte-13|0xFB |0xEB |0xDB |0xCB |0xBB |0xAB |0x9B |0x8B |
|byte-14|0xFC |0xEC |0xDC |0xCC |0xBC |0xAC |0x9C |0x8C |
|byte-15|0xFD |0xED |0xDD |0xCD |0xBD |0xAD |0x9D |0x8D |
|byte-16|0xFE |0xEE |0xDE |0xCE |0xBE |0xAE |0x9E |0x8E |
|byte-17|0xFF |0xEF |0xDF |0xCF |0xBF |0xAF |0x9F |0x8F |


例

```
コントローラ                         　　　　　　　　 エアコン
(IP=192.168.1.1)　　　　　　　                 (IP=192.168.1.2)
(EOJ=0x05FF01)　　　　　　　                   (EOJ=0x013001)
    |  Get Property map(Anno)                       |
    |  IP SRC:192.168.1.1, DST:192.168.1.2          |
    |  1081 0004 05FF01 013001 62 01 9D 00          |
    | --------------------------------------------> |
    |                                               |
    |  IP SRC:192.168.1.2, DST:192.168.1.1          |
    |  1081 0004 013001 05FF01 72 01 9D 05 04808FA0B0
    | <-------------------------------------------- |
    |                                               |
    |  Get Property map(Set)                        |
    |  IP SRC:192.168.1.1, DST:192.168.1.2          |
    |  1081 0004 05FF01 013001 62 01 9E 00          |
    | --------------------------------------------> |
    |                                               |
    |  IP SRC:192.168.1.2, DST:192.168.1.1          |
    |  1081 0004 013001 05FF01 72 01 9E 06 05808FA0B0B3
    | <-------------------------------------------- |
    |                                               |
    |  Get Property map(Get)                        |
    |  IP SRC:192.168.1.1, DST:192.168.1.2          |
    |  1081 0004 05FF01 013001 62 01 9F 00          |
    | --------------------------------------------> |
    |                                               |
    |  IP SRC:192.168.1.2, DST:192.168.1.1          |
    |  1081 0004 013001 05FF01 72 01 9F 07 06808FA0B0B3BB
    | <-------------------------------------------- |
```

5) メーカコード(EPC=0x83)の取得  
機器オブジェクトのメーカ名が分かると、機器の特定に利用できる場合がある。必須プロパティの一つであるメーカコード(EPC=0x8A)を取得することでメーカ名がわかる。

```
Destination IP: IP address of the device
SEOJ: 0x05FF01
DEOJ: EOJ of the device object
ESV:  0x62(GET)
OPC:  1
EPC:  0x8A
```

例

```
コントローラ                         　　　　　　　　 エアコン
(IP=192.168.1.1)　　　　　　　                 (IP=192.168.1.2)
(EOJ=0x05FF01)　　　　　　　                   (EOJ=0x013001)
    |  IP SRC:192.168.1.1, DST:192.168.1.2          |
    |  1081 0004 05FF01 013001 62 01 8A 00          |
    | --------------------------------------------> |
    |                                               |
    |  IP SRC:192.168.1.2, DST:192.168.1.1          |
    |  1081 0004 013001 05FF01 72 01 8A 03 000068   |
    | <-------------------------------------------- |
```

メーカコードは３byteであり、メーカコードとメーカ名の対応表はエコーネットコンソーシアムの会員のみに公開されている。実機からメーカコードを取得すればメーカ名との対応は明らかなので、神奈川工科大学が所有する機器のメーカコードとメーカ名の対応表を第６章に示す。  


### <a id="Chap2.8">2.8 異常処理</a>
ECHONET Liteのリクエストメッセージ(ESV=0x60, 61, 62, 63, 6E)を受信した時の異常処理を説明する(reference:第２部4.2.2, 第２部付録１, システム設計指針2.2)。条件に応じて以下のどれかの処理を行う。  

- レスポンスを送信しない。命令を無視する。
- メッセージの受理処理(\*)を行う。命令を無視する。  
- SNAを送信する。命令を無視する。  

(\*)ESV=0x60の場合は「レスポンスを送信しない。」、ESV=0x61の場合は「レスポンスESV=0x71を送信する」、ESV=0x6Eの場合は「レスポンスESV=0x7Eを送信する」。

#### 2.8.1 Message frame error
条件：メッセージがECHONET Liteのフレームフォーマットに適合しない場合。  
処理：レスポンスを送信しない。命令を無視する。  
備考：SetGetはフレーム構造が異なることに注意すること。

#### 2.8.2 EHD error
条件：EHDが0x1081でない場合。  
処理：レスポンスを送信しない。命令を無視する。

#### 2.8.3 DEOJ error
条件：DEOJで指定されたオブジェクトが存在しない場合。  
処理：レスポンスを送信しない。命令を無視する。  
備考：インスタンスコードが0x00の場合の処理に注意。  
(reference:第２部付録１)  

#### 2.8.4 ESV error
条件：ESVが規格で定義された値以外の場合。  
処理：レスポンスを送信しない。命令を無視する。  
(reference:第２部付録１)  

#### 2.8.5 EPC error
条件：EPCが、指定されたESVの処理を実装しない場合。  
処理：SNAをレスポンスする。命令を無視する。  
(reference:第２部付録１)  

#### 2.8.6 EDT error
条件：SetでEDTのサイズが規格と異なる場合  
処理：以下のどちらの処理でも構わない。  
(A)：レスポンスを送信しない。命令を無視する。  
(B)：SNAをレスポンスする。命令を無視する。  
(reference:第２部付録１)  

条件：SetでEDTの値が規格外の場合（例：仕様の値域外の値、状態として定義されていない値）  
処理（推奨）：メッセージ受理の処理(\*)を行う。命令を無視する。  
処理（これでも構わない）：SNAをレスポンスする。命令を無視する。  
(\*)ESV=0x60の場合は「レスポンスを送信しない。」、ESV=0x61の場合は「レスポンスESV=0x71を送信する」、ESV=0x6Eの場合は「レスポンスESV=0x7Eを送信する」。  
(reference:システム設計指針2.2)  

##### Get\_SNA をレスポンスする例（PDC=0x00でレスポンスする）

```
リクエスト：コントローラ(0x05FF01) -> エアコン(0x013001)
10 81 00 01 05 FF 01 01 30 01 62  01  A2  00
<---> <---> <------> <------> <-> <-> <-> <->
 EHD   TID    SEOJ     DEOJ   ESV OPC EPC PDC
 
レスポンス：エアコン(0x013001) -> コントローラ(0x05FF01)
10 81 00 01 01 30 01 05 FF 01 52  01  A2  00
<---> <---> <------> <------> <-> <-> <-> <->
 EHD   TID    SEOJ     DEOJ   ESV OPC EPC PDC
 
```

##### SetC\_SNA をレスポンスする例（SetCのEDT値をレスポンスする）

```
リクエスト：コントローラ(0x05FF01) -> エアコン(0x013001)
10 81 00 01 05 FF 01 01 30 01 61  01  80  02  30 00
<---> <---> <------> <------> <-> <-> <-> <-> <--->
 EHD   TID    SEOJ     DEOJ   ESV OPC EPC PDC EDT
 
レスポンス：エアコン(0x013001) -> コントローラ(0x05FF01)
10 81 00 01 01 30 01 05 FF 01 51  01  80  02  30 00
<---> <---> <------> <------> <-> <-> <-> <-> <--->
 EHD   TID    SEOJ     DEOJ   ESV OPC EPC PDC EDT
 
```

### <a id="Chap2.9">2.9 プロパティの値と実装</a>

#### EDTが状態の場合  
機器は規格で定義されている全ての状態を実装する必要はない。  

条件：実装していない状態のSetリクエストを受信した場合  
処理（推奨）：メッセージの受理処理(\*)を行う。命令を無視する。(reference:システム設計指針2.1(3), 2.2)  
処理（これでも構わない）：SNAをレスポンスする。命令を無視する。(reference:システム設計指針2.2)  
(\*)ESV=0x60の場合は「レスポンスを送信しない。」、ESV=0x61の場合は「レスポンスESV=0x71を送信する」、ESV=0x6Eの場合は「レスポンスESV=0x7Eを送信する」。  
 
例：エアコンのEPC=0xB0(運転モード)の状態は 0x41(自動),0x42(冷房),0x43(暖房),0x44(除湿),0x45(送風),0x40(その他)が定義されている。冷房専用のエアコンがメッセージ(ESV=SetC, EPC=0xB0, EDT=0x43)を受信した場合、Set\_Resをレスポンスするが、内部の動作モードの変更は行わない。プロパティの値も変更しない。

#### EDTがレベルの場合  
機器は規格で定義されている全てのレベル値を内部状態として実装する必要はない。  

例えばエアコンのEPC=0xA0(風量設定)など、強弱設定を８段階のレベル(0x31~0x38)で指定するプロパティが多く存在する。このようなプロパティにおいて、内部状態を弱・中・強の３段階しか持たない場合、EDTの全てのレベル値を実機のいずれかの状態にマッピングすることが推奨される(reference:システム設計指針2.2)。以下にEDTの値と内部状態のマッピング例を示す。  

| EDT値 |0x31|0x32|0x33|0x34|0x35|0x36|0x37|0x38|
|:------|:--|:--|:--|:--|:--|:--|:--|:--
|内部状態|弱|弱|中|中|中|中|強|強|強

Getの動作に関しては以下の２通りの実装が考えられる。コントローラの立場としては(A)の実装が望ましい。  
(A) Setした値がレスポンスされる。  
(B) 内部状態に対応した代表値（例：0x31(弱), 0x35(中), 0x38(強))がレスポンスされる(reference:システム設計指針2.1(2))  

上記のマッピング例でSet(EDT=0x33)を実行すると、内部状態は「中」になる。ここでGetを実行すると(A)の場合は0x33が、(B)の場合は0x35がレスポンスされる。

#### EDTが数値の場合
##### A. 実機器の値域が規格の値域の内側の場合
Set要求のEDT値が規格内の値であるが実装の値を超える場合、実装の端の値を設定する(reference:システム設計指針2.1(1))。例えば下図のように規格の値域の最大値が50かつ実装の値域の最大値が40の場合にSetC(EDT=45)を受信したときには、プロパティの値を40とする(reference:システム設計指針2.1(1))。ただし、実装の都合でSNAをレスポンスし、命令を無視しても構わない(reference:システム設計指針2.2)。

```
　　　　　     0               40   50
規格の値域     |<------------------>|
実機の値域     |<------------->|
　　　　　                       |
                              Set 45
```

##### B. 実機器の値域が規格の値域を超える場合
内部状態が規格の値域を超える時にGet要求を受信した場合、OverflowまたはUnderflowに対応する値をレスポンスする(reference:第２部6.2.2(2))。例えば下図のように規格の値域の最大値が50かつ実装の値域の最大値が60で内部状態が55の場合にGetを受信したときには、Overflowに対応する値0xFFをレスポンスする。

```
　　　　　     0                    50   60
規格の値域     |<------------------>|
実機の値域     |<----------------------->|
　　　　　                             |
                             内部状態 55
```

### <a id="Chap2.10">2.10 複数命令の処理</a>
EPC, PDC, EDTのセットを命令(operation)と呼ぶ。１つのECHONET Liteメッセージに複数のoperationを記述することができる。例えばESV=0x62(Get)でEPC=0x80, 0x81, 0x82の３つのプロパティの読み出しリクエストを一度に送信することができる。一度に送るoperationの個数をOPCに設定する(reference:第２部4.2.3)。エラー処理が複雑なのでプロトタイピング時にはOPC=0x01だけの実装も可能であるが、AIF認証では複数OPCのメッセージの送受信に関する試験がある。

#### Get: 正常処理
リクエストは、EPCとPDC(=0x00)の組み合わせをOPCが示す回数繰り返して記述する。  
レスポンスはEPC, PDC, EDTの組み合わせをOPCが示す回数繰り返して記述する。  
以下はOPC=0x03の場合の例を示す。

```
リクエスト：コントローラ(0x05FF01) -> エアコン(0x013001)
10 81 00 01 05 FF 01 01 30 01 62  03  80   00   81   00   82   00  
<---> <---> <------> <------> <-> <-> <--> <--> <--> <--> <--> <--> 
 EHD   TID    SEOJ     DEOJ   ESV OPC EPC1 PDC1 EPC2 PDC2 EPC3 PDC3
 
レスポンス：エアコン(0x013001) -> コントローラ(0x05FF01)
10 81 00 01 01 30 01 05 FF 01 72  03  80   01   31   81   01   00   82   04   00004400  
<---> <---> <------> <------> <-> <-> <--> <--> <--> <--> <--> <--> <--> <--> <------> 
 EHD   TID    SEOJ     DEOJ   ESV OPC EPC1 PDC1 EDT1 EPC2 PDC2 EDT2 EPC3 PDC3 EDT3
```

#### Get: 異常処理
一つでもoperationが処理できない場合は ESV=0x52(Get\_SNA)でレスポンスする。  
処理できないEPCはPDC=0x00としてレスポンスする。  
以下は３番目のoperationが異常処理の例を示す。

```
リクエスト：コントローラ(0x05FF01) -> エアコン(0x013001)
10 81 00 01 05 FF 01 01 30 01 62  03  80   00   81   00   A2   00  
<---> <---> <------> <------> <-> <-> <--> <--> <--> <--> <--> <--> 
 EHD   TID    SEOJ     DEOJ   ESV OPC EPC1 PDC1 EPC2 PDC2 EPC3 PDC3
 
レスポンス：エアコン(0x013001) -> コントローラ(0x05FF01)
10 81 00 01 01 30 01 05 FF 01 52  03  80   01   31   81   01   00   A2   00  
<---> <---> <------> <------> <-> <-> <--> <--> <--> <--> <--> <--> <--> <-->
 EHD   TID    SEOJ     DEOJ   ESV OPC EPC1 PDC1 EDT1 EPC2 PDC2 EDT2 EPC3 PDC3
```

#### Set: 正常処理
SetIの場合、全てのoperationを受け付けた場合はレスポンスは不要。  
以下はSetCの場合の例を示す。

```
リクエスト：コントローラ(0x05FF01) -> エアコン(0x013001)
10 81 00 01 05 FF 01 01 30 01 61  02  80   01   30   81   01   08
<---> <---> <------> <------> <-> <-> <--> <--> <--> <--> <--> <--> 
 EHD   TID    SEOJ     DEOJ   ESV OPC EPC1 PDC1 EDT1 EPC2 PDC2 EDT2
 
レスポンス：エアコン(0x013001) -> コントローラ(0x05FF01)
10 81 00 01 01 30 01 05 FF 01 71  02  80   00   81   00
<---> <---> <------> <------> <-> <-> <--> <--> <--> <-->
 EHD   TID    SEOJ     DEOJ   ESV OPC EPC1 PDC1 EPC2 PDC2
 
```

#### Set: 異常処理
一つでもoperationが処理できない場合は ESV=0x50(SetI\_SNA)または0x51(SetC\_SNA)でレスポンスする。  
処理できたEPCはPDC=0x00、処理できないEPCはリクエストされたEDT値をレスポンスする。  
以下は１番目のoperationが異常処理の例を示す。

```
リクエスト：コントローラ(0x05FF01) -> エアコン(0x013001)
10 81 00 01 05 FF 01 01 30 01 61  02  80   01   32   81   01   08
<---> <---> <------> <------> <-> <-> <--> <--> <--> <--> <--> <--> 
 EHD   TID    SEOJ     DEOJ   ESV OPC EPC1 PDC1 EDT1 EPC2 PDC2 EDT2
 
レスポンス：エアコン(0x013001) -> コントローラ(0x05FF01)
10 81 00 01 01 30 01 05 FF 01 51  02  80   01   32   81   00
<---> <---> <------> <------> <-> <-> <--> <--> <--> <--> <-->
 EHD   TID    SEOJ     DEOJ   ESV OPC EPC1 PDC1 EDT1 EPC2 PDC2
 
```

### <a id="Chap2.11">2.11 スマート電力量メータ</a>
低圧スマート電力量メータ(EOJ=0x0288)と高圧スマートメータ(EOJ=0x028A)に関する注意事項を述べる。  
#### 低圧スマート電力量メータ(EOJ=0x0288)
- 物理レイヤーはWi-SUN(無線)またはG3-PLC(有線)
- IPv6で一対一の接続のみ
- PANA 認証

#### 高圧スマートメータ(EOJ=0x028A)
- 物理レイヤーは有線LAN
- IPv6

## <a id="Chap3">3. 発展編</a>

### <a id="Chap3.1">3.1 SetGet</a>
ESV=0x6E(SetGet)を使うとSetとGetのoperationを一つのメッセージで送信することができる(reference:第２部4.2.3.4)。ただしメッセージのフレーム構成が他のものと異なる。異常処理はかなり複雑である。SetGetの処理の実装はオプションであり、実装しない場合はSetGet\_SNA(OPCSet=0, OPCGet=0)をレスポンスする。  

SetGetを使用したメッセージの中でSetとGetで同一のEPCを指定した場合、SetとGetのどちらが先に実行されるかは実装依存である(reference:第２部4.2.3.4)。一方、システム設計指針ではSetの処理後にGetの処理を行うことを実装の指針としている（reference:システム設計指針2.6）。

#### データパッケトのフレーム構成
OPC\_Setの後にSetCのoperation(EPC, PDC, EDT)が列挙され、その後OPC\_Getの後にGetのoperation(EPC, PDC)が列挙される。

```
リクエスト
+---+---+----+----+----+------+----+----+----+---+----+----+----+------+----+----+---+----+----+
|EHD|TID|SEOJ|DEOJ|ESV |OPCSet|EPC1|PDC1|EDT1|...|EPCm|PDCm|EDTm|OPCGet|EPC1|PDC1|...|EPCn|PDCn|
|   |   |    |    |0x6E|  (m) |    |    |    |   |    |    |    |  (n) |    |0x00|   |    |0x00|
+---+---+----+----+----+------+----+----+----+---+----+----+----+------+----+----+---+----+----+

レスポンス
+---+---+----+----+----+------+----+----+---+----+----+------+----+----+----+---+----+----+----+
|EHD|TID|SEOJ|DEOJ|ESV |OPCSet|EPC1|PDC1|...|EPCm|PDCm|OPCGet|EPC1|PDC1|EDT1|...|EPCn|PDCn|EDTn|
|   |   |    |    |0x7E|  (m) |    |0x00|   |    |0x00|  (n) |    |    |    |   |    |    |    |
+---+---+----+----+----+------+----+----+---+----+----+------+----+----+----+---+----+----+----+
```

#### 正常処理の例：OPC\_Set=2, OPC\_Get=2
レスポンスは、Setの場合はPDC=0x00、Getの場合はプロパティの値

```
リクエスト：コントローラ(0x05FF01) -> エアコン(0x013001)
10 81 00 01 05 FF 01 01 30 01 6E  02     80   01   30   81   01   08   02     A0   00   B0   00  
<---> <---> <------> <------> <-> <----> <--> <--> <--> <--> <--> <--> <----> <--> <--> <--> <-->
 EHD   TID    SEOJ     DEOJ   ESV OPCSet EPC1 PDC1 EDT1 EPC2 PDC2 EDT2 OPCGet EPC1 PDC1 EPC2 PDC2
 
レスポンス：エアコン(0x013001) -> コントローラ(0x05FF01)
10 81 00 01 01 30 01 05 FF 01 7E  02     80   00   81   00   02     A0   01   41   B0   01   42  
<---> <---> <------> <------> <-> <----> <--> <--> <--> <--> <----> <--> <--> <--> <--> <--> <-->
 EHD   TID    SEOJ     DEOJ   ESV OPCSet EPC1 PDC1 EPC2 PDC2 OPCGet EPC1 PDC1 EDT1 EPC2 PDC2 EDT2
 
```

#### 異常処理の例：OPC\_Set=2, OPC\_Get=2
一つでもoperationが処理できない場合は ESV=0x5E(SetGet\_SNA)とし、Setが処理できない場合はSetのEDT値を、Getが処理できない場合はPDC=0x00としてレスポンスする。以下はSetの１番目とGetの２番目のoperationが異常処理の例である。

```
リクエスト：コントローラ(0x05FF01) -> エアコン(0x013001)
10 81 00 01 05 FF 01 01 30 01 6E  02     80   01   30   81   01   08   02     A0   00   B0   00  
<---> <---> <------> <------> <-> <----> <--> <--> <--> <--> <--> <--> <----> <--> <--> <--> <-->
 EHD   TID    SEOJ     DEOJ   ESV OPCSet EPC1 PDC1 EDT1 EPC2 PDC2 EDT2 OPCGet EPC1 PDC1 EPC2 PDC2
 
レスポンス：エアコン(0x013001) -> コントローラ(0x05FF01)
10 81 00 01 01 30 01 05 FF 01 5E  02     80   01   30   81   00   02     A0   01   41   B0   00  
<---> <---> <------> <------> <-> <----> <--> <--> <--> <--> <--> <----> <--> <--> <--> <--> <-->
 EHD   TID    SEOJ     DEOJ   ESV OPCSet EPC1 PDC1 EDT1 EPC2 PDC2 OPCGet EPC1 PDC1 EDT1 EPC2 PDC2
 
```

#### SetGet の処理を実装しない場合
SetGetの処理の実装はオプションである。処理を実装しない場合、SetGetに対してSetGet\_SNA(OPCSet=0, OPCGet=0)のレスポンスをする。

```
リクエスト：コントローラ(0x05FF01) -> エアコン(0x013001)
10 81 00 01 05 FF 01 01 30 01 6E  02     80   01   30   81   01   08   02     A0   00   B0   00  
<---> <---> <------> <------> <-> <----> <--> <--> <--> <--> <--> <--> <----> <--> <--> <--> <-->
 EHD   TID    SEOJ     DEOJ   ESV OPCSet EPC1 PDC1 EDT1 EPC2 PDC2 EDT2 OPCGet EPC1 PDC1 EPC2 PDC2
 
レスポンス：エアコン(0x013001) -> コントローラ(0x05FF01)
10 81 00 01 01 30 01 05 FF 01 5E  00     00
<---> <---> <------> <------> <-> <----> <---->
 EHD   TID    SEOJ     DEOJ   ESV OPCSet OPCGet
 
```

### <a id="Chap3.2">3.2 現実的な実装について</a>
　実験用のプロトタイピングと製品化前提のケースで、ECHONET Liteの現実的な実装について説明する。プロトタイピングでは動作確認のための最低限の実装とする。製品化前提の場合には認証を考慮する必要がある。認証に関しては[第４章](#Chap4)を参照のこと。

#### 3.2.1 コントローラ（プロトタイピング）

　コントローラはGetやSetCの命令を受信してレスポンスする必要は基本的に無いので、とりあえず実装しなくても構わない。ただし、制御対象の機器がコントローラの素性を確認する場合には、以下のEPCのGet命令を受信した場合にレスポンスすることをお勧めする。

##### Node profile
|EPC | プロパティ名|EDT値（例）
|:---|:------------|:----
|0x82| Version情報 |0x010D0100: V1.13
|0x83| 識別番号    |0xFEFFFFFF000102030405060708090A0B0C
|0x8A| メーカコード |0xFFFFFF: 実験用のコード (reference:Appendix 2.6)

##### Super class 
|EPC | プロパティ名|EDT値（例）
|:---|:-----------|:----
|0x80| 動作状態    | 0x30: ON
|0x8A| メーカコード | 0xFFFFFF: 実験用のコード (reference:Appendix 2.6)

コントローラが送信するコマンドはGetとSetCを利用し、OPC=1とする。  

#### 3.2.2 機器（プロトタイピング）

　コントローラが製品である場合、機器はNode profileと機器オブジェクトの必須プロパティの実装が必要。<br>　Node profileのEPC=0x83（識別番号）は0xFE(1byte) + メーカコード(3byte) + Unique ID(13byte)で構成される。以下の値は、実験用のメーカコード0xFFFFFFとUnique ID:000102030405060708090A0B0C の例である。ネットワーク内でこの機器を１台しか使わない場合はこの値でよいが、複数台使う可能性がある場合はそれぞれの機器の識別番号をユニークな値(\*)にすること。同一の値の場合、コントローラが誤動作する可能性がある。  

(\*) 値をマニュアルで変更するか、乱数やMACアドレスを利用してユニークな値をプログラムで生成する。

プロパティの値の例

##### Node profile
|EPC | プロパティ名|EDT値（例）
|:---|:------------|:----
|0x80| 動作状態     |0x30:ON
|0x82| Version情報 |0x010D0100: V1.13
|0x83| 識別番号    |0xFEFFFFFF000102030405060708090A0B0C
|0x8A| メーカコード |0xFFFFFF: 実験用のコード (reference:Appendix 2.6)
|0x9D| 状変アナウンスプロパティマップ|0x0280D5
|0x9E| Set プロパティマップ    |0x00
|0x9F| Get プロパティマップ    |0x0B8082838A9D9E9FD3D5D6D7
|0xD3| 自ノードインスタンス数     |0x000001
|0xD4| 自ノードクラス数     |0x0002
|0xD5| インスタンスリスト通知     |0x01013001
|0xD6| 自ノードインスタンスリストS  |0x01013001
|0xD7| 自ノードクラスリストS     |0x010130

##### 機器オブジェクトのSuper class 
|EPC | プロパティ名|EDT値（例）
|:---|:-----------|:----
|0x80| 動作状態    | 0x30: ON
|0x81| 設置場所 | 0x00: 未設定
|0x82| 規格Version情報 | 0x00004C00: Release L
|0x88| 異常発生状態 | 0x42: 異常なし
|0x8A| メーカコード | 0xFFFFFF: 実験用のコード (reference:Appendix 2.6)
|0x9D| 状変アナウンスプロパティマップ |実装に合わせる
|0x9E| Setプロパティマップ |実装に合わせる
|0x9F| Getプロパティマップ |実装に合わせる

実装は、機器が受信するサービスのうちGetとSetCに対応し、Get\_ResとSet\_Resをレスポンスする。OPCは1のみ対応する。エラー処理は特に必要ない。起動時処理のNode profileのEPC=0xD5のINFは実装する。

#### 3.2.3 コントローラ（製品化前提）

- Node profileオブジェクトと機器オブジェクトの必須プロパティは実装が必要。
- Node profileオブジェクトのEPC=0xBF（個体識別情報）は実装しない(\*)。
- 機器オブジェクトのEPC=0x81(設置場所)のプロパティ値は1byteと17byteで定義されているが、1byteの実装が主流。
- 機器オブジェクトのEPC=0x83(識別番号）は必須ではないが実装する。
- リクエスト送信に使用するESVは 0x61(SetC), 0x62(Get)。SetI, INF\_REQ, SetGetは使わない。
- 通知送信に使用するESVは 0x73(INF)。0x74(INFC)は使わない。
- Getを送信後レスポンスを受信するまでに時間がかかるプロパティが存在する。例えば低圧スマート電力量メータの履歴値など。タイムアウトはプロパティごとに考慮が必要。
- SetCを送信後、Set動作を確認するためにプロパティ値をGetするのが望ましい。Setした値とGetした値が異なる場合があるので注意。
    - 値が変わらない場合
        - Set動作の完了に時間がかかる場合
        - Setした値を機器が実装していない場合
    - 値が変わっているが、Setした値でない場合
        - 機器側の実装の都合
- リクエストの受信は全てのESV(0x60,0x61,0x62,0x63,0x6E)に対応する必要がある。
- INFC(0x74)を受信したら、EPC, EDTの値にかかわらずINFC\_Res(0x7A)をレスポンスする。
- SetGetを受信した場合、SetGet\_SNA(OPCSet=0, OPCGet=0)をレスポンスする。
- 送信コマンドの複数OPC対応が必要かどうかは、対応するAIF認証仕様を確認すること。

(\*) ECHONET Lite V1.01までは必須であった。Node profileを識別するために規定されたが、仕様が複雑すぎるので、V1.1以降はEPC=0x83がNode profileを識別するために使われることになった。

#### 3.2.4 機器（製品化前提）

- Node profileオブジェクトと機器オブジェクトの必須プロパティは実装が必要
- Node profileオブジェクトのEPC=0xBF:個体識別情報 は実装しない(\*)
- 機器オブジェクトのEPC=0x81(設置場所)のプロパティ値は1byteと17byteで定義されているが、1byteの実装が主流。
- 機器オブジェクトのEPC=0x83(識別番号）は必須ではないが実装を推奨する(reference:システム設計指針2.8)。
- 通知送信に使用するESVは 0x73(INF)。0x74(INFC)は使わない。
- リクエストの受信は全てのESV(0x60,0x61,0x62,0x63,0x6E)に対応する必要がある。
- INFC(0x74)を受信したら、EPC, EDTの値にかかわらずINFC\_Res(0x7A)をレスポンスする。
- SetGetを受信した場合、SetGet\_SNA(OPCSet=0, OPCGet=0)をレスポンスする。
- 受信コマンドの複数OPC対応が必要かどうかは対応するAIF認証仕様を確認すること。

(\*) ECHONET Lite V1.01までは必須であった。Node profileを識別するために規定されたが、仕様が複雑すぎるので、V1.1以降はEPC=0x83がNode profileを識別するために使われることになった。

### <a id="Chap3.3">3.3 遠隔操作設定</a>
　機器オブジェクトのSuper classのEPC=0x93（遠隔操作設定）プロパティは、電気用品安全法の遠隔操作に関連する項目である(reference:APPENDIX2.16, システム設計指針第５章)。例えば下図のように宅外からスマートフォンを利用して宅内のエアコンを制御する場合に、HEMS Controllerとエアコンの間の通信にECHONET Liteを利用するシステム構成を想定している。遠隔操作設定プロパティは必須プロパティではなく、実装もめんどうなのでおすすめではないが、以下に遠隔操作設定の説明を行う。<br>

```
                       ------------------------------------------
                      /                                          \
                     /                                            \
                     ---+                                      +---
   +-------+            |  +----------+ ECHONET +-----------+  |
   | Smart |            |  |   HEMS   |  Lite   |    Air    |  |
   | phone | ------------->|Controller| ------> |Conditioner|  |
   +-------+            |  +----------+         +-----------+  |
                        +--------------------------------------+

```

#### コントローラ側の実装
コントローラがインターネットなど宅外からの制御を受信し、宅内の機器をエコーネットライトで制御(Set)する場合は、EPC=0x93, EDT=0x42（公衆回線経由操作）の命令を1st operationとして追加する。以下にエアコンの電源をON遠隔操作でONにする場合の例を示す。

> 1081 0001 05FF01 013001 61 02 930142 800130

- 宅外からの命令でECHONET LiteのGetの操作をする場合は、遠隔操作プロパティを追加しない。  
- コントローラのGUIでの操作などの宅内制御の場合は、遠隔操作プロパティを追加しない。

#### 機器側の実装
- 受信したSetコマンドに、EPC=0x93, EDT=0x42（公衆回線経由操作）命令がある場合<br>
    - 遠隔操作プロパティ(EPC=0x93)の値を、0x42:公衆回線経由操作にする。
    - 機器ごとに操作内容を判断して動作する(法律の解釈も関係するので実装は自己責任）。

- 受信したSetコマンドにEPC=0x93命令がない場合<br>
    - 遠隔操作プロパティ(EPC=0x93)の値を、0x41:公衆回線未経由操作にする。
    - Setの動作を行う。

- 機器のパネルやリモコンでの操作を行った場合
    - 遠隔操作プロパティ(EPC=0x93)の値を、0x41:公衆回線未経由操作にする。

### <a id="Chap3.4">3.4 送信専用ノード</a>
電池駆動のセンサーなどを想定して送信専用機器の扱いが定義されている。

- 送信専用ノードのProfile node objectのEOJは0x0EF002(reference:第２部4.3.1)
- 定期的にProfile node objectのインスタンスリスト(EPC=0xD6)をINFでMulticastする(reference:システム設計指針:2.10)
- 機器オブジェクト詳細規定の必須の項目の対応は必要ではない（reference:第２部6.2.3)

### <a id="Chap3.5">3.5 ECHONET Liteのバージョン間の違い</a>
2019年8月時点でこれまでECHONET Liteは以下のバージョンがリリースされている。バージョン間の違いに関して留意すべき項目を記述する。    
> Version 1.00, 1.01, 1.10, 1.11, 1.12, 1.13  

Version | 留意すべき項目
:---|:-----------
1.00 -> 1.01| 特になし
1.01 -> 1.10| - ノードプロファイル EPC=0xBF(個体識別情報)のアクセスルールに関して、<br>　V1.01までは必須。V1.10は必須ではない(reference:第2部6.11.1表6-7)。<br>- ノードプロファイル EPC=0x83(識別番号)のデータフォーマットに関して、<br>　V1.01までは 9 or 17byte。V1.10は17byteのみ。<br>- コントローラによる機器探索のシーケンスに関して、<br>　Version 1.01までよく行なわれていた方式：<br>　　ノードプロファイル EPC=0xD5(インスタンスリスト)にINF\_REQをマルチキャスト<br>　Ver. 1.10で明記された推奨方式(reference:第5部)：<br>　　ノードプロファイル EPC=0xD6(インスタンスリストＳ)にGETをマルチキャスト<br>- 送信専用機器のDEOJの値に関して、<br>　V1.01までは特別な記述なし。V1.10は0x0EF002(reference:第２部6.11.1)。
1.10 -> 1.11|- WAN経由の操作に関して指針の追加(reference:第５部６章)。
1.11 -> 1.12| 特になし
1.12 -> 1.13| - 第5部の中身をすべて「ECHONET Liteシステム設計指針」として、ECHONET Lite規格から独立させた。

## <a id="Chap4">4. 認証制度</a>
### <a id="Chap4.1">4.1 エコーネットコンソーシアム</a>
[エコーネットコンソーシアム](https://echonet.jp)はECHONET Liteの規格を策定する団体である。国際標準化や認証制度策定などの活動も行っている。ECHONET Liteの規格は公開され無償で利用できるが、認証を受けるためにはコンソーシアムの会員である必要がある。<br>
[認証制度](https://echonet.jp/about/certification_system/)には「ECHNONET Lite 規格認証制度」と「AIF仕様認証制度」がある。認証に関する仕様書はエコーネットコンソーシアムの会員のみに公開されている。
### <a id="Chap4.2">4.2 ECHNONET Lite 規格認証制度</a>
ECHNONET Lite 規格認証はECHONET Liteの規格の中で全ての機器に共通の項目が正しく実装されているかを確認する。コンソーシアムは試験ツールを提供していない。試験項目の例を以下に示す。

- Node profileのプロパティのアクセス
- 機器オブジェクトのスーパークラスのプロパティのアクセス
- 起動時のインスタンスリスト通知の確認

### <a id="Chap4.3">4.3 AIF仕様認証制度</a>
AIF仕様認証は、機器オブジェクトごとのプロパティにアクセスしその値を確認する。コンソーシアムは会員に対して試験ツールを提供している。2019年8月時点で以下のカテゴリーの機器とそれを制御するコントローラは、ECHNONET Lite 規格認証を取得したのちにAIF仕様認証を取得することが求められる。

- 低圧/高圧スマート電力量メータ
- 家庭用エアコン
- 住宅用太陽光発電
- 瞬間式給湯器
- 照明機器
- 蓄電池
- 電気自動車充放電器／電気自動車充電器
- 電気自動車充放電器	 	 
- 燃料電池
- 業務用パッケージエアコン
- 業務用ショーケース
- 照明システム
- 拡張照明システム

機種によっては、AIF仕様で搭載必須のプロパティが追加されている場合もあるので注意すること。また複数OPCを前提の試験項目もある。

## <a id="ChapAnnex">付録. メーカコード</a>
神奈川工科大学が所有する機器のメーカコードとメーカ名の対応表  

| Manufacture code | Manufacture name
:------------------|:---------------------
| 0x000005 | シャープ株式会社
| 0x000006 | 三菱電機株式会社
| 0x000008 | ダイキン工業株式会社
| 0x000009 | 日本電気株式会社
| 0x00000B | パナソニック株式会社
| 0x000016 | 株式会社東芝
| 0x00001B | 東芝ライテック株式会社
| 0x000022 | 日立アプライアンス株式会社
| 0x00004E | 富士通株式会社
| 0x000053 | 株式会社ユビキタス
| 0x000059 | リンナイ株式会社
| 0x00005E | 株式会社GWソーラー
| 0x000060 | 株式会社ソニーコンピュータサイエンス研究所
| 0x000063 | 河村電器産業株式会社
| 0x000064 | オムロン株式会社
| 0x000069 | 東芝ライフスタイル株式会社
| 0x00006C | ニチコン株式会社
| 0x00006F | 株式会社バッファロー
| 0x000072 | 株式会社エナリス
| 0x000077 | 神奈川工科大学
| 0x000078 | 日立マクセル株式会社
| 0x00007D | POWERTECH INDUSTRIAL
| 0x000086 | 西日本電信電話株式会社
| 0x00008A | 株式会社富士通ゼネラル
| 0x0000A3 | 中部電力株式会社
| 0x0000AA | 株式会社テンフィートライト
| 0x0000AE | 四国電力株式会社
| 0x0000B5 | 中国電力株式会社
| 0x0000B6 | 文化シヤッター株式会社
| 0x0000B8 | 北海道電力株式会社

